summaryrefslogtreecommitdiff
path: root/resources/jquery.ui/jquery.ui.selectable.js
diff options
context:
space:
mode:
Diffstat (limited to 'resources/jquery.ui/jquery.ui.selectable.js')
-rw-r--r--resources/jquery.ui/jquery.ui.selectable.js15
1 files changed, 6 insertions, 9 deletions
diff --git a/resources/jquery.ui/jquery.ui.selectable.js b/resources/jquery.ui/jquery.ui.selectable.js
index bc707d36..e3b91328 100644
--- a/resources/jquery.ui/jquery.ui.selectable.js
+++ b/resources/jquery.ui/jquery.ui.selectable.js
@@ -1,10 +1,9 @@
-
/*
* jQuery UI Selectable 1.8.2
*
- * Copyright (c) 2010 AUTHORS.txt (http://jqueryui.com/about)
- * Dual licensed under the MIT (MIT-LICENSE.txt)
- * and GPL (GPL-LICENSE.txt) licenses.
+ * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
+ * Dual licensed under the MIT or GPL Version 2 licenses.
+ * http://jquery.org/license
*
* http://docs.jquery.com/UI/Selectables
*
@@ -13,7 +12,7 @@
* jquery.ui.mouse.js
* jquery.ui.widget.js
*/
-(function($) {
+(function( $, undefined ) {
$.widget("ui.selectable", $.ui.mouse, {
options: {
@@ -90,8 +89,6 @@ $.widget("ui.selectable", $.ui.mouse, {
$(options.appendTo).append(this.helper);
// position helper (lasso)
this.helper.css({
- "z-index": 100,
- "position": "absolute",
"left": event.clientX,
"top": event.clientY,
"width": 0,
@@ -263,7 +260,7 @@ $.widget("ui.selectable", $.ui.mouse, {
});
$.extend($.ui.selectable, {
- version: "1.8.2"
+ version: "1.8.11"
});
})(jQuery);
@@ -1,10 +1,9 @@
/*
- * jQuery UI Selectable 1.8.2
+ * jQuery UI Selectable 1.8.11
*